@@ -44,20 +44,23 @@ class KGpgRootNode : public KGpgExpandableNode
 
 private:
 	int m_groups;
-	int m_deleting;
 
 protected:
-	virtual void readChildren() Q_DECL_OVERRIDE;
+	void readChildren() Q_DECL_OVERRIDE;
 
 public:
 	explicit KGpgRootNode(KGpgItemModel *model);
 	virtual ~KGpgRootNode();
 
-	virtual KgpgCore::KgpgItemType getType() const;
+	KgpgCore::KgpgItemType getType() const Q_DECL_OVERRIDE;
 
 	/**
 	 * Create new group nodes
-	 * @param groups list of group names to create
+	 * @param groups list of group names and keys to create
+	 *
+	 * The format of each entry of groups is name:keys, where keys is
+	 * a list of key ids separated by semicolons. This is the format
+	 * that is output by "gpg --list-config --with-colons".
 	 */
 	void addGroups(const QStringList &groups);
 	void addKeys(const QStringList &ids = QStringList());
@@ -110,19 +113,6 @@ public:
 	 */
 	int groupChildren() const;
 
-	/**
-	 * Return a pointer to this object or Q_NULLPTR
-	 *
-	 * This returns a pointer to this object if the object will persist,
-	 * i.e. is not currently in destruction. If the object is already
-	 * cleaning up Q_NULLPTR is returned.
-	 */
-	KGpgRootNode *asRootNode();
-	/**
-	 * @overload
-	 */
-	const KGpgRootNode *asRootNode() const;
-
 Q_SIGNALS:
 	void newKeyNode(KGpgKeyNode *);
 };
